# hydra_router/__init__.py
#
#   Hydra Router
#    Author: Nadim-Daniel Ghaznavi
#    Copyright: (c) 2025-2026 Nadim-Daniel Ghaznavi
#    GitHub: https://github.com/NadimGhaznavi/hydra_router
#    Website: https://hydra-router.readthedocs.io/en/latest
#    License: GPL 3.0

"""
Hydra Router - ZeroMQ-based client-server communication framework.

This package provides HydraServer and HydraClient classes for simple
REQ/REP messaging patterns using ZeroMQ.
"""

__version__ = "0.1.0"

# Classes will be available after implementation
__all__ = ["HydraServer", "HydraClient"]
